==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1ControllerRevisionListFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1ControllerRevisionListFluent<A extends V1ControllerRevisionListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A addToItems(int index,V1ControllerRevision item);
    public A setToItems(int index,V1ControllerRevision item);
    public A addToItems(V1ControllerRevision... items);
    public A addAllToItems(Collection<V1ControllerRevision> items);
    public A removeFromItems(V1ControllerRevision... items);
    public A removeAllFromItems(Collection<V1ControllerRevision> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<V1ControllerRevision> getItems();
    public List<V1ControllerRevision> buildItems();
    public V1ControllerRevision buildItem(int index);
    public V1ControllerRevision buildFirstItem();
    public V1ControllerRevision buildLastItem();
    public V1ControllerRevision buildMatchingItem(io.kubernetes.client.fluent.Predicate<V1ControllerRevisionBuilder> predicate);
    public A withItems(List<V1ControllerRevision> items);
    public A withItems(V1ControllerRevision... items);
    public Boolean hasItems();
    public V1ControllerRevisionListFluent.ItemsNested<A> addNewItem();
    public V1ControllerRevisionListFluent.ItemsNested<A> addNewItemLike(V1ControllerRevision item);
    public V1ControllerRevisionListFluent.ItemsNested<A> setNewItemLike(int index,V1ControllerRevision item);
    public V1ControllerRevisionListFluent.ItemsNested<A> editItem(int index);
    public V1ControllerRevisionListFluent.ItemsNested<A> editFirstItem();
    public V1ControllerRevisionListFluent.ItemsNested<A> editLastItem();
    public V1ControllerRevisionListFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<V1ControllerRevisionBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ListMeta getMetadata();
    public V1ListMeta buildMetadata();
    public A withMetadata(V1ListMeta metadata);
    public Boolean hasMetadata();
    public V1ControllerRevisionListFluent.MetadataNested<A> withNewMetadata();
    public V1ControllerRevisionListFluent.MetadataNested<A> withNewMetadataLike(V1ListMeta item);
    public V1ControllerRevisionListFluent.MetadataNested<A> editMetadata();
    public V1ControllerRevisionListFluent.MetadataNested<A> editOrNewMetadata();
    public V1ControllerRevisionListFluent.MetadataNested<A> editOrNewMetadataLike(V1ListMeta item);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ControllerRevisionFluent<V1ControllerRevisionListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ListMetaFluent<V1ControllerRevisionListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1ControllerRevisionListFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1ControllerRevisionListFluent<A extends V1ControllerRevisionListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,V1ControllerRevision item);
    public A setToItems(int index,V1ControllerRevision item);
    public A addToItems(V1ControllerRevision... items);
    public A addAllToItems(Collection<V1ControllerRevision> items);
    public A removeFromItems(V1ControllerRevision... items);
    public A removeAllFromItems(Collection<V1ControllerRevision> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<V1ControllerRevision> getItems();
    public List<V1ControllerRevision> buildItems();
    public V1ControllerRevision buildItem(int index);
    public V1ControllerRevision buildFirstItem();
    public V1ControllerRevision buildLastItem();
    public V1ControllerRevision buildMatchingItem(io.kubernetes.client.fluent.Predicate<V1ControllerRevisionBuilder> predicate);
    public Boolean hasMatchingItem(io.kubernetes.client.fluent.Predicate<V1ControllerRevisionBuilder> predicate);
    public A withItems(List<V1ControllerRevision> items);
    public A withItems(V1ControllerRevision... items);
    public Boolean hasItems();
    public V1ControllerRevisionListFluent.ItemsNested<A> addNewItem();
    public V1ControllerRevisionListFluent.ItemsNested<A> addNewItemLike(V1ControllerRevision item);
    public V1ControllerRevisionListFluent.ItemsNested<A> setNewItemLike(int index,V1ControllerRevision item);
    public V1ControllerRevisionListFluent.ItemsNested<A> editItem(int index);
    public V1ControllerRevisionListFluent.ItemsNested<A> editFirstItem();
    public V1ControllerRevisionListFluent.ItemsNested<A> editLastItem();
    public V1ControllerRevisionListFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<V1ControllerRevisionBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ListMeta getMetadata();
    public V1ListMeta buildMetadata();
    public A withMetadata(V1ListMeta metadata);
    public Boolean hasMetadata();
    public V1ControllerRevisionListFluent.MetadataNested<A> withNewMetadata();
    public V1ControllerRevisionListFluent.MetadataNested<A> withNewMetadataLike(V1ListMeta item);
    public V1ControllerRevisionListFluent.MetadataNested<A> editMetadata();
    public V1ControllerRevisionListFluent.MetadataNested<A> editOrNewMetadata();
    public V1ControllerRevisionListFluent.MetadataNested<A> editOrNewMetadataLike(V1ListMeta item);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ControllerRevisionFluent<V1ControllerRevisionListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ListMetaFluent<V1ControllerRevisionListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}
